from distutils.core import setup
	
setup(
    name = "rcknester",
    version = "1.2.0",
    py_modules = ["rcknester"],
    author = "hfpython",
    author_email = "hfpython@headfirstlabs.com",
    url = "http://www.headfirstlabs.com",
    description = "A simple printer of nested lists"
)	
